@@ -1,37 +1,23 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "magnetlink.h"
-#include <QUrlQuery>
+#include <QRegularExpression>
 #include <QStringList>
-#include <util/log.h>
+#include <QUrlQuery>
 #include <util/error.h>
+#include <util/log.h>
 
 namespace bt
 {
-
 MagnetLink::MagnetLink()
 {
 }
 
-MagnetLink::MagnetLink(const MagnetLink& mlink)
+MagnetLink::MagnetLink(const MagnetLink &mlink)
     : magnet_string(mlink.magnet_string)
     , info_hash(mlink.info_hash)
     , torrent_url(mlink.torrent_url)
@@ -41,12 +27,12 @@ MagnetLink::MagnetLink(const MagnetLink& mlink)
 {
 }
 
-MagnetLink::MagnetLink(const QUrl& mlink)
+MagnetLink::MagnetLink(const QUrl &mlink)
 {
     parse(mlink);
 }
 
-MagnetLink::MagnetLink(const QString& mlink)
+MagnetLink::MagnetLink(const QString &mlink)
 {
     parse(QUrl(mlink));
 }
@@ -55,7 +41,7 @@ MagnetLink::~MagnetLink()
 {
 }
 
-MagnetLink& MagnetLink::operator=(const bt::MagnetLink& mlink)
+MagnetLink &MagnetLink::operator=(const bt::MagnetLink &mlink)
 {
     magnet_string = mlink.magnet_string;
     info_hash = mlink.info_hash;
@@ -66,7 +52,7 @@ MagnetLink& MagnetLink::operator=(const bt::MagnetLink& mlink)
     return *this;
 }
 
-bool MagnetLink::operator==(const bt::MagnetLink& mlink) const
+bool MagnetLink::operator==(const bt::MagnetLink &mlink) const
 {
     return info_hash == mlink.infoHash();
 }
@@ -79,42 +65,41 @@ static QList<QUrl> GetTrackers(const QUrl &url)
     return result;
 }
 
-void MagnetLink::parse(const QUrl& url)
+void MagnetLink::parse(const QUrl &url)
 {
     if (url.scheme() != QLatin1String("magnet")) {
-        Out(SYS_GEN | LOG_NOTICE) << "Invalid protocol of magnet link "
-                                  << url << endl;
+        Out(SYS_GEN | LOG_NOTICE) << "Invalid protocol of magnet link " << url << endl;
         return;
     }
 
     torrent_url = QUrlQuery(url).queryItemValue(QStringLiteral("to"), QUrl::FullyDecoded);
-    //magnet://description-of-content.btih.HASH(-HASH)*.dht/path/file?x.pt=&x.to=
+    // magnet://description-of-content.btih.HASH(-HASH)*.dht/path/file?x.pt=&x.to=
 
     // TODO automatically select these files and prefetches from here
     path = QUrlQuery(url).queryItemValue(QStringLiteral("pt"));
     if (path.isEmpty() && url.path() != QLatin1String("/")) {
         // TODO find out why RemoveTrailingSlash does not work
-        path = url.adjusted(QUrl::StripTrailingSlash).path().remove(QRegExp(QLatin1String("^/")));
+        path = url.adjusted(QUrl::StripTrailingSlash).path().remove(QRegularExpression(QLatin1String("^/")));
     }
 
     QString xt = QUrlQuery(url).queryItemValue(QLatin1String("xt"));
-    if (xt.isEmpty()
-        || !xt.startsWith(QLatin1String("urn:btih:"))) {
-        QRegExp btihHash(QLatin1String("([^\\.]+).btih"));
-        if (btihHash.indexIn(url.host()) != -1) {
-            QString primaryHash = btihHash.cap(1).split('-')[0];
+    if (xt.isEmpty() || !xt.startsWith(QLatin1String("urn:btih:"))) {
+        static QRegularExpression btihHash(QLatin1String("([^\\.]+).btih"));
+
+        const QRegularExpressionMatch match = btihHash.match(url.host());
+
+        if (match.hasMatch()) {
+            QString primaryHash = match.captured(1).split('-')[0];
             xt = QLatin1String("urn:btih:") + primaryHash;
         } else {
-            Out(SYS_GEN | LOG_NOTICE) << "No hash found in magnet link "
-                                      << url << endl;
+            Out(SYS_GEN | LOG_NOTICE) << "No hash found in magnet link " << url << endl;
             return;
         }
     }
 
     QString ih = xt.mid(9);
     if (ih.length() != 40 && ih.length() != 32) {
-        Out(SYS_GEN | LOG_NOTICE) << "Hash has not valid length in magnet link "
-                                  << url << endl;
+        Out(SYS_GEN | LOG_NOTICE) << "Hash has not valid length in magnet link " << url << endl;
         return;
     }
 
@@ -139,7 +124,7 @@ void MagnetLink::parse(const QUrl& url)
     }
 }
 
-Uint8 MagnetLink::charToHex(const QChar& ch)
+Uint8 MagnetLink::charToHex(const QChar &ch)
 {
     if (ch.isDigit())
         return ch.digitValue();
@@ -189,4 +174,3 @@ QString MagnetLink::base32ToHexString(const QString &s)
 }
 
 }
-
